@@ -1,4 +1,4 @@
-# coding: utf8
+# -*- coding: utf-8 -*-
 """
     CSS Selectors based on XPath
     ============================
@@ -13,10 +13,10 @@
 
 """
 
-from cssselect.parser import (parse, Selector, SelectorError,
-                              SelectorSyntaxError)
+from cssselect.parser import (parse, Selector, FunctionalPseudoElement,
+                              SelectorError, SelectorSyntaxError)
 from cssselect.xpath import GenericTranslator, HTMLTranslator, ExpressionError
 
 
-VERSION = '0.8'
+VERSION = '1.0.3'
 __version__ = VERSION
